[Libreoffice-commits] core.git: sd/source

2020-02-02 Thread dldld (via logerrit)
 sd/source/ui/sidebar/SlideBackground.cxx |   21 +++--
 1 file changed, 15 insertions(+), 6 deletions(-)

New commits:
commit 32cf800f88be1348bf0ad5297cf353566aeac790
Author: dldld 
AuthorDate: Wed Dec 18 20:38:21 2019 +0100
Commit: Samuel Mehrbrodt 
CommitDate: Mon Feb 3 08:44:20 2020 +0100

tdf#127137 Allow assigning of master slide to multiple slides

The old code was only able to set the master page for the first selected 
page which
has now been changed to be set in all currently selected pages

Change-Id: Id6826f87ed7d12abb220ea1871af06626d67112e
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/85424
Tested-by: Jenkins
Reviewed-by: Samuel Mehrbrodt 

diff --git a/sd/source/ui/sidebar/SlideBackground.cxx 
b/sd/source/ui/sidebar/SlideBackground.cxx
index ee24a21cfe47..85a9671b171b 100644
--- a/sd/source/ui/sidebar/SlideBackground.cxx
+++ b/sd/source/ui/sidebar/SlideBackground.cxx
@@ -20,6 +20,10 @@
 #include 
 #include 
 #include 
+#include 
+#include 
+#include 
+#include 
 #include "SlideBackground.hxx"
 #include 
 #include 
@@ -1160,17 +1164,22 @@ IMPL_LINK_NOARG(SlideBackground, AssignMasterPage, 
weld::ComboBox&, void)
 SdDrawDocument* pDoc = pDocSh ? pDocSh->GetDoc() : nullptr;
 if (!pDoc)
 return;
-sal_uInt16 nSelectedPage = SDRPAGE_NOTFOUND;
+
+auto pSSVS = sd::slidesorter::SlideSorterViewShell::GetSlideSorter(mrBase);
+if (pSSVS == nullptr)
+return;
+
+auto& rSSController = pSSVS->GetSlideSorter().GetController();
+auto& rPageSelector = rSSController.GetPageSelector();
+
 for( sal_uInt16 nPage = 0; nPage < 
pDoc->GetSdPageCount(PageKind::Standard); nPage++ )
 {
-if (pDoc->GetSdPage(nPage,PageKind::Standard)->IsSelected())
+if (rPageSelector.IsPageSelected(nPage))
 {
-nSelectedPage = nPage;
-break;
+OUString aLayoutName(mxMasterSlide->get_active_text());
+pDoc->SetMasterPage(nPage, aLayoutName, pDoc, false, false);
 }
 }
-OUString aLayoutName(mxMasterSlide->get_active_text());
-pDoc->SetMasterPage(nSelectedPage, aLayoutName, pDoc, false, false);
 }
 
 IMPL_LINK_NOARG(SlideBackground, EditMasterHdl, weld::Button&, void)
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: include/IwyuFilter_include.yaml include/xmloff solenv/clang-format xmloff/inc xmloff/qa xmloff/source

2020-02-02 Thread Noel Grandin (via logerrit)
 include/IwyuFilter_include.yaml  |   11 ---
 solenv/clang-format/blacklist|   10 +-
 xmloff/inc/PageMasterStyleMap.hxx|4 ++--
 xmloff/inc/XMLEmbeddedObjectExportFilter.hxx |6 +++---
 xmloff/inc/fasttokenhandler.hxx  |4 ++--
 xmloff/inc/pch/precompiled_xo.hxx|2 +-
 xmloff/inc/xmltabe.hxx   |6 +++---
 xmloff/qa/unit/tokenmap-test.cxx |2 +-
 xmloff/source/core/XMLEmbeddedObjectExportFilter.cxx |2 +-
 xmloff/source/core/fasttokenhandler.cxx  |2 +-
 xmloff/source/core/xmlexp.cxx|2 +-
 xmloff/source/core/xmlimp.cxx|2 +-
 xmloff/source/draw/sdpropls.cxx  |2 +-
 xmloff/source/style/PageMasterExportPropMapper.cxx   |2 +-
 xmloff/source/style/PageMasterImportContext.cxx  |2 +-
 xmloff/source/style/PageMasterImportPropMapper.cxx   |2 +-
 xmloff/source/style/PageMasterPropHdlFactory.cxx |2 +-
 xmloff/source/style/PageMasterPropMapper.cxx |2 +-
 xmloff/source/style/PageMasterStyleMap.cxx   |2 +-
 xmloff/source/style/PagePropertySetContext.cxx   |2 +-
 xmloff/source/style/WordWrapPropertyHdl.cxx  |2 +-
 xmloff/source/style/XMLFootnoteSeparatorExport.cxx   |2 +-
 xmloff/source/style/XMLFootnoteSeparatorImport.cxx   |2 +-
 xmloff/source/style/XMLPageExport.cxx|2 +-
 xmloff/source/style/impastpl.cxx |2 +-
 xmloff/source/style/xmlaustp.cxx |2 +-
 xmloff/source/style/xmltabe.cxx  |2 +-
 xmloff/source/text/txtexppr.hxx  |2 +-
 28 files changed, 37 insertions(+), 48 deletions(-)

New commits:
commit cdd3c6851027a8a66baefcc4f1e58b7c4ad4ee6a
Author: Noel Grandin 
AuthorDate: Sun Feb 2 19:31:46 2020 +0200
Commit: Noel Grandin 
CommitDate: Mon Feb 3 08:12:09 2020 +0100

move some xmloff/ headers inside the module

Change-Id: I57e97da952c18c33af85a8fe24ebf021fc0631d9
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/87828
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/include/IwyuFilter_include.yaml b/include/IwyuFilter_include.yaml
index ce9a9100dff6..85507711eb80 100644
--- a/include/IwyuFilter_include.yaml
+++ b/include/IwyuFilter_include.yaml
@@ -465,19 +465,11 @@ blacklist:
 # Needed for macros
 - comphelper/servicehelper.hxx
 - tools/diagnose_ex.h
-include/xmloff/XMLEmbeddedObjectExportFilter.hxx:
-# base class has to be a complete type
-- com/sun/star/lang/XInitialization.hpp
-- com/sun/star/lang/XServiceInfo.hpp
-- com/sun/star/xml/sax/XExtendedDocumentHandler.hpp
 include/xmloff/attrlist.hxx:
 # base class has to be a complete type
 - com/sun/star/lang/XUnoTunnel.hpp
 - com/sun/star/util/XCloneable.hpp
 - com/sun/star/xml/sax/XAttributeList.hpp
-include/xmloff/fasttokenhandler.hxx:
-# base class has to be a complete type
-- com/sun/star/xml/sax/XFastTokenHandler.hpp
 include/xmloff/unointerfacetouniqueidentifiermapper.hxx:
 # base class has to be a complete type
 - com/sun/star/uno/XInterface.hpp
@@ -510,9 +502,6 @@ blacklist:
 - com/sun/star/xml/sax/XExtendedDocumentHandler.hpp
 - com/sun/star/xml/sax/XFastDocumentHandler.hpp
 - com/sun/star/xml/sax/XFastParser.hpp
-include/xmloff/xmltabe.hxx:
-# Needed for css shortcut
-- sal/types.h
 include/svtools/accessibleruler.hxx:
 # base class has to be a complete type
 - com/sun/star/accessibility/XAccessible.hpp
diff --git a/solenv/clang-format/blacklist b/solenv/clang-format/blacklist
index 454e57c4d1d1..e69df4d693de 100644
--- a/solenv/clang-format/blacklist
+++ b/solenv/clang-format/blacklist
@@ -7911,18 +7911,15 @@ include/xmloff/HatchStyle.hxx
 include/xmloff/ImageStyle.hxx
 include/xmloff/MarkerStyle.hxx
 include/xmloff/NamedBoolPropertyHdl.hxx
-include/xmloff/PageMasterStyleMap.hxx
 include/xmloff/ProgressBarHelper.hxx
 include/xmloff/SchXMLExportHelper.hxx
 include/xmloff/SchXMLImportHelper.hxx
 include/xmloff/SchXMLSeriesHelper.hxx
 include/xmloff/SettingsExportHelper.hxx
 include/xmloff/SinglePropertySetInfoCache.hxx
-include/xmloff/WordWrapPropertyHdl.hxx
 include/xmloff/XMLBase64ImportContext.hxx
 include/xmloff/XMLCharContext.hxx
 include/xmloff/XMLConstantsPropertyHandler.hxx
-include/xmloff/XMLEmbeddedObjectExportFilter.hxx
 include/xmloff/XMLEventExport.hxx
 include/xmloff/XMLEventsImportContext.hxx
 include/xmloff/XMLFilterServiceNames.h
@@ -7947,7 +7944,6 @@ include/xmloff/contextid.hxx
 include/xmloff/controlpropertyhdl.hxx
 include/xmloff/dllapi.h
 include/xmloff/families.hxx
-include/xmloff/fasttokenhandler.hxx
 include/xmloff/formlayerexport.hxx
 include/xmloff/formlayerimport.hxx
 include/xmloff/i18nmap.hxx
@@ -799

Re: Want to contribute under GSoC 20

2020-02-02 Thread Ilmari Lauhakangas

On 3.2.2020 5.59, Mudit Jain wrote:

Hi,

I want to contribute to LibreOffice under GSoC 20.
Can you please tell me where to start or assign me a task?
How should I proceed further to contribute or get a head start?


No organisation has yet been selected for GSoC.

To get prepared, please follow 
https://wiki.documentfoundation.org/Development/GetInvolved


Complete a build and submit patches for easy hacks.

Ilmari
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] online.git: cypress_test/integration_tests

2020-02-02 Thread Tamás Zolnai (via logerrit)
 cypress_test/integration_tests/common/helper.js |2 +-
 cypress_test/integration_tests/mobile/insert_object_spec.js |6 --
 2 files changed, 1 insertion(+), 7 deletions(-)

New commits:
commit e7d8c7456fb56188eb13df79a16f892cf2f19f2e
Author: Tamás Zolnai 
AuthorDate: Mon Feb 3 06:23:55 2020 +0100
Commit: Tamás Zolnai 
CommitDate: Mon Feb 3 06:37:36 2020 +0100

cypress: mobile: Use a bigger mobile screen size.

Change-Id: Ica3598dd2f963b46891114a67c76f0d4da205c11

diff --git a/cypress_test/integration_tests/common/helper.js 
b/cypress_test/integration_tests/common/helper.js
index 6c8163119..e9cc62328 100644
--- a/cypress_test/integration_tests/common/helper.js
+++ b/cypress_test/integration_tests/common/helper.js
@@ -9,7 +9,7 @@ function loadTestDoc(fileName, mobile) {
});
 
if (mobile === true) {
-   cy.viewport('iphone-3');
+   cy.viewport('iphone-6');
}
 
// Open test document
diff --git a/cypress_test/integration_tests/mobile/insert_object_spec.js 
b/cypress_test/integration_tests/mobile/insert_object_spec.js
index a0a2cafb1..19200f48c 100644
--- a/cypress_test/integration_tests/mobile/insert_object_spec.js
+++ b/cypress_test/integration_tests/mobile/insert_object_spec.js
@@ -48,9 +48,6 @@ describe('Insert objects via insertion wizard.', function() {
cy.get('.mobile-wizard.ui-text')
.should('be.visible');
 
-   // Scroll to the bottom
-   cy.get('#mobile-wizard-content').scrollTo(0, 1000);
-
// Push insert table button
cy.get('.inserttablecontrols button')
.should('be.visible')
@@ -73,9 +70,6 @@ describe('Insert objects via insertion wizard.', function() {
cy.get('.mobile-wizard.ui-text')
.should('be.visible');
 
-   // Scroll to the bottom
-   cy.get('#mobile-wizard-content').scrollTo(0, 1000);
-
// Change rows and columns
cy.get('.inserttablecontrols #rows .sinfieldcontrols .plus')
.click();
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] online.git: 4 commits - cypress_test/integration_tests

2020-02-02 Thread Tamás Zolnai (via logerrit)
 cypress_test/integration_tests/common/helper.js  |   
13 
 cypress_test/integration_tests/desktop/copy_paste_spec.js|
6 
 cypress_test/integration_tests/desktop/example_desktop_test_spec.js  |
9 
 cypress_test/integration_tests/desktop/shape_operations_spec.js  |
7 
 cypress_test/integration_tests/mobile/apply_font_spec.js |
2 
 cypress_test/integration_tests/mobile/apply_paragraph_properties_spec.js |
2 
 cypress_test/integration_tests/mobile/bottom_toolbar_spec.js |  
239 ++
 cypress_test/integration_tests/mobile/focus_spec.js  |
2 
 cypress_test/integration_tests/mobile/insert_field_spec.js   |
2 
 cypress_test/integration_tests/mobile/insert_formatting_mark_spec.js |
2 
 cypress_test/integration_tests/mobile/insert_object_spec.js  |
2 
 cypress_test/integration_tests/mobile/mobile_wizard_state_spec.js|
2 
 cypress_test/integration_tests/mobile/styles_spec.js |
9 
 cypress_test/integration_tests/mobile/toolbar_spec.js|
2 
 14 files changed, 280 insertions(+), 19 deletions(-)

New commits:
commit 7a140da9c9f554ff073ba59656d15d5ccacc2ea2
Author: Tamás Zolnai 
AuthorDate: Mon Feb 3 05:37:26 2020 +0100
Commit: Tamás Zolnai 
CommitDate: Mon Feb 3 05:53:22 2020 +0100

cypress: Make this desktop test case more stable.

Change-Id: I9aeb6a4c87a2a5a8a0ade320e993ad85ca4c9e82

diff --git 
a/cypress_test/integration_tests/desktop/example_desktop_test_spec.js 
b/cypress_test/integration_tests/desktop/example_desktop_test_spec.js
index 7d1691414..824656bd2 100644
--- a/cypress_test/integration_tests/desktop/example_desktop_test_spec.js
+++ b/cypress_test/integration_tests/desktop/example_desktop_test_spec.js
@@ -19,7 +19,7 @@ describe('Example test suit 1', function() {
cy.get('#tb_editbar_item_bold').click();
 
// Remove selection and do a reselection
-   cy.get('#document-container').click();
+   cy.get('#document-container').type('{leftarrow}');
cy.get('.leaflet-marker-icon').should('not.be.visible');
 
cy.get('#document-container').dblclick();
commit 1cfc1c59e9b29ebcd42b4ef8d276a055ca3dcf81
Author: Tamás Zolnai 
AuthorDate: Mon Feb 3 05:34:25 2020 +0100
Commit: Tamás Zolnai 
CommitDate: Mon Feb 3 05:53:22 2020 +0100

cypress: Check the admin console to make sure the test document is closed.

Change-Id: I485e8596a30c7bb1efae140143627078cde66bca

diff --git a/cypress_test/integration_tests/common/helper.js 
b/cypress_test/integration_tests/common/helper.js
index 631df38b9..6c8163119 100644
--- a/cypress_test/integration_tests/common/helper.js
+++ b/cypress_test/integration_tests/common/helper.js
@@ -83,13 +83,16 @@ function copyTextToClipboard() {
.should('not.exist');
 }
 
-function afterAllMobile() {
-   cy.visit('http://localhost:9980/loleaflet/' +
-   Cypress.env('WSD_VERSION_HASH') +
-   '/loleaflet.html?file_path=file://');
+function afterAll() {
+   // Make sure that the document is closed
+   
cy.visit('http://admin:admin@localhost:9980/loleaflet/dist/admin/admin.html');
+   cy.get('#doclist')
+   .should('exist');
+   cy.get('#doclist tr')
+   .should('not.exist', {timeout : 1});
 }
 
 module.exports.loadTestDoc = loadTestDoc;
 module.exports.selectAllMobile = selectAllMobile;
 module.exports.copyTextToClipboard = copyTextToClipboard;
-module.exports.afterAllMobile = afterAllMobile;
+module.exports.afterAll = afterAll;
diff --git 
a/cypress_test/integration_tests/desktop/example_desktop_test_spec.js 
b/cypress_test/integration_tests/desktop/example_desktop_test_spec.js
index dafad9dad..7d1691414 100644
--- a/cypress_test/integration_tests/desktop/example_desktop_test_spec.js
+++ b/cypress_test/integration_tests/desktop/example_desktop_test_spec.js
@@ -1,8 +1,13 @@
-/* global describe it cy require*/
+/* global describe it cy require afterEach*/
 
 var helper

Want to contribute under GSoC 20

2020-02-02 Thread Mudit Jain
Hi,

I want to contribute to LibreOffice under GSoC 20.
Can you please tell me where to start or assign me a task?
How should I proceed further to contribute or get a head start?

Thanks and Regards,
Mudit Jain
+91-7206307664 | cipher...@gmail.com


[image: Mailtrack]

Sender
notified by
Mailtrack

02/02/20,
21:38:17
___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-commits] core.git: officecfg/registry

2020-02-02 Thread Maxim Monastirsky (via logerrit)
 officecfg/registry/data/org/openoffice/Office/UI/WriterCommands.xcu |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 18b2cecfef3dd26bac15522667b465802ff3f96b
Author: Maxim Monastirsky 
AuthorDate: Mon Feb 3 01:41:21 2020 +0200
Commit: Adolfo Jayme Barrientos 
CommitDate: Mon Feb 3 05:36:47 2020 +0100

Styles > Text Body menu didn't work in non-English UI

Capitalization of "Body" present only in the UI name
of the style, but that might be something completely
different in other languages. We need to reference
the style using its programmatic name instead.

Change-Id: I2d980a225d6f5346d378947621ace3a17e0a8f81
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/87842
Tested-by: Jenkins
Reviewed-by: Adolfo Jayme Barrientos 

diff --git 
a/officecfg/registry/data/org/openoffice/Office/UI/WriterCommands.xcu 
b/officecfg/registry/data/org/openoffice/Office/UI/WriterCommands.xcu
index 7cc090ceeed0..a40119acbfb9 100644
--- a/officecfg/registry/data/org/openoffice/Office/UI/WriterCommands.xcu
+++ b/officecfg/registry/data/org/openoffice/Office/UI/WriterCommands.xcu
@@ -3267,7 +3267,7 @@
   Text Body Paragraph Style
 
 
-  .uno:StyleApply?Style:string=Text 
Body&FamilyName:string=ParagraphStyles
+  .uno:StyleApply?Style:string=Text 
body&FamilyName:string=ParagraphStyles
 
 
   9
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] help.git: source/text

2020-02-02 Thread Stanislav Horacek (via logerrit)
 source/text/sbasic/shared/compatibilitymode.xhp |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 81a9ef3e5260ccabaeadb36304e529eac520decb
Author: Stanislav Horacek 
AuthorDate: Sun Feb 2 22:19:37 2020 +0100
Commit: Adolfo Jayme Barrientos 
CommitDate: Mon Feb 3 05:18:55 2020 +0100

fix function name in page title

Change-Id: I8899ae50ffb59d925bbf80c7403ffc949f0a3f14
Reviewed-on: https://gerrit.libreoffice.org/c/help/+/87838
Tested-by: Jenkins
Reviewed-by: Adolfo Jayme Barrientos 

diff --git a/source/text/sbasic/shared/compatibilitymode.xhp 
b/source/text/sbasic/shared/compatibilitymode.xhp
index da9c4023d..9ce7f7613 100644
--- a/source/text/sbasic/shared/compatibilitymode.xhp
+++ b/source/text/sbasic/shared/compatibilitymode.xhp
@@ -10,7 +10,7 @@
 -->
 
 
-CompatibleMode function
+CompatibilityMode function
 /text/sbasic/shared/compatibilitymode.xhp
 
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: helpcontent2

2020-02-02 Thread Stanislav Horacek (via logerrit)
 helpcontent2 |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit dcbd3bf2db29d9b55eeaf1ca3c74e4ff33325ccd
Author: Stanislav Horacek 
AuthorDate: Mon Feb 3 05:18:55 2020 +0100
Commit: Gerrit Code Review 
CommitDate: Mon Feb 3 05:18:55 2020 +0100

Update git submodules

* Update helpcontent2 from branch 'master'
  to 81a9ef3e5260ccabaeadb36304e529eac520decb
  - fix function name in page title

Change-Id: I8899ae50ffb59d925bbf80c7403ffc949f0a3f14
Reviewed-on: https://gerrit.libreoffice.org/c/help/+/87838
Tested-by: Jenkins
Reviewed-by: Adolfo Jayme Barrientos 

diff --git a/helpcontent2 b/helpcontent2
index a7c86802627b..81a9ef3e5260 16
--- a/helpcontent2
+++ b/helpcontent2
@@ -1 +1 @@
-Subproject commit a7c86802627ba84c6990354e020aa34b2738ec57
+Subproject commit 81a9ef3e5260ccabaeadb36304e529eac520decb
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] online.git: loleaflet/src

2020-02-02 Thread Tamás Zolnai (via logerrit)
 loleaflet/src/control/Control.MobileWizard.js |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 9b64bd381995662a65306659409f78865c47f318
Author: Tamás Zolnai 
AuthorDate: Mon Feb 3 03:37:39 2020 +0100
Commit: Tamás Zolnai 
CommitDate: Mon Feb 3 03:37:39 2020 +0100

Fix font / highlight color dropdown doesn't work

Regression from:
298f4297c21f4b7cd5836b90bafcc803f13adb00

Change-Id: Ic0001157b3866cbf3293812573c33d6b4a18a9d6

diff --git a/loleaflet/src/control/Control.MobileWizard.js 
b/loleaflet/src/control/Control.MobileWizard.js
index 02b90407b..92445e5a3 100644
--- a/loleaflet/src/control/Control.MobileWizard.js
+++ b/loleaflet/src/control/Control.MobileWizard.js
@@ -291,7 +291,7 @@ L.Control.MobileWizard = L.Control.extend({
this._reset();
 
var mWizardContentLength;
-   if (data.children[0].type == 'menuitem' || 
data.children[0].type == 'htmlcontrol')
+   if (data.children[0].type == 'menuitem' || 
data.children[0].children === undefined)
mWizardContentLength = data.children.length;
else mWizardContentLength = 
data.children[0].children.length;
 
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: cui/source include/svx svx/source sw/source

2020-02-02 Thread Caolán McNamara (via logerrit)
 cui/source/inc/paragrph.hxx|   10 +-
 cui/source/tabpages/paragrph.cxx   |   10 +-
 include/svx/dlgctrl.hxx|4 ++--
 include/svx/relfld.hxx |4 ++--
 svx/source/dialog/dlgctrl.cxx  |2 +-
 svx/source/dialog/relfld.cxx   |   10 +-
 svx/source/sidebar/paragraph/ParaPropertyPanel.cxx |   10 +-
 svx/source/sidebar/paragraph/ParaPropertyPanel.hxx |   10 +-
 svx/source/sidebar/paragraph/ParaSpacingWindow.cxx |   10 +-
 svx/source/sidebar/paragraph/ParaSpacingWindow.hxx |   10 +-
 sw/source/uibase/sidebar/PageFormatPanel.cxx   |4 ++--
 sw/source/uibase/sidebar/PageFormatPanel.hxx   |4 ++--
 sw/source/uibase/sidebar/TableEditPanel.cxx|4 ++--
 sw/source/uibase/sidebar/TableEditPanel.hxx|4 ++--
 14 files changed, 48 insertions(+), 48 deletions(-)

New commits:
commit 69ccba90135f4dfc22d4cb823e10cf4794ddaa04
Author: Caolán McNamara 
AuthorDate: Sat Feb 1 21:18:41 2020 +
Commit: Caolán McNamara 
CommitDate: Sun Feb 2 21:40:36 2020 +0100

rename RelativeField back to SvxRelativeField

Change-Id: Iadac47f83aae0f7403f3391e3dd45bef52ad347a
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/87832
Tested-by: Jenkins
Reviewed-by: Caolán McNamara 
Tested-by: Caolán McNamara 

diff --git a/cui/source/inc/paragrph.hxx b/cui/source/inc/paragrph.hxx
index b068fe643808..b57199d91551 100644
--- a/cui/source/inc/paragrph.hxx
+++ b/cui/source/inc/paragrph.hxx
@@ -52,18 +52,18 @@ private:
 SvxParaPrevWindow m_aExampleWin;
 
 // indention
-std::unique_ptr m_xLeftIndent;
+std::unique_ptr m_xLeftIndent;
 
 std::unique_ptr m_xRightLabel;
-std::unique_ptr m_xRightIndent;
+std::unique_ptr m_xRightIndent;
 
 std::unique_ptr m_xFLineLabel;
-std::unique_ptr m_xFLineIndent;
+std::unique_ptr m_xFLineIndent;
 std::unique_ptr m_xAutoCB;
 
 // distance
-std::unique_ptr m_xTopDist;
-std::unique_ptr m_xBottomDist;
+std::unique_ptr m_xTopDist;
+std::unique_ptr m_xBottomDist;
 std::unique_ptr m_xContextualCB;
 
 // line spacing
diff --git a/cui/source/tabpages/paragrph.cxx b/cui/source/tabpages/paragrph.cxx
index c8ef51b1245c..b712a7555d8f 100644
--- a/cui/source/tabpages/paragrph.cxx
+++ b/cui/source/tabpages/paragrph.cxx
@@ -678,14 +678,14 @@ 
SvxStdParagraphTabPage::SvxStdParagraphTabPage(weld::Container* pPage, weld::Dia
 , nWidth(11905 /*567 * 50*/)
 , nMinFixDist(0)
 , bRelativeMode(false)
-, m_xLeftIndent(new 
RelativeField(m_xBuilder->weld_metric_spin_button("spinED_LEFTINDENT", 
FieldUnit::CM)))
+, m_xLeftIndent(new 
SvxRelativeField(m_xBuilder->weld_metric_spin_button("spinED_LEFTINDENT", 
FieldUnit::CM)))
 , m_xRightLabel(m_xBuilder->weld_label("labelFT_RIGHTINDENT"))
-, m_xRightIndent(new 
RelativeField(m_xBuilder->weld_metric_spin_button("spinED_RIGHTINDENT", 
FieldUnit::CM)))
+, m_xRightIndent(new 
SvxRelativeField(m_xBuilder->weld_metric_spin_button("spinED_RIGHTINDENT", 
FieldUnit::CM)))
 , m_xFLineLabel(m_xBuilder->weld_label("labelFT_FLINEINDENT"))
-, m_xFLineIndent(new 
RelativeField(m_xBuilder->weld_metric_spin_button("spinED_FLINEINDENT", 
FieldUnit::CM)))
+, m_xFLineIndent(new 
SvxRelativeField(m_xBuilder->weld_metric_spin_button("spinED_FLINEINDENT", 
FieldUnit::CM)))
 , m_xAutoCB(m_xBuilder->weld_check_button("checkCB_AUTO"))
-, m_xTopDist(new 
RelativeField(m_xBuilder->weld_metric_spin_button("spinED_TOPDIST", 
FieldUnit::CM)))
-, m_xBottomDist(new 
RelativeField(m_xBuilder->weld_metric_spin_button("spinED_BOTTOMDIST", 
FieldUnit::CM)))
+, m_xTopDist(new 
SvxRelativeField(m_xBuilder->weld_metric_spin_button("spinED_TOPDIST", 
FieldUnit::CM)))
+, m_xBottomDist(new 
SvxRelativeField(m_xBuilder->weld_metric_spin_button("spinED_BOTTOMDIST", 
FieldUnit::CM)))
 , 
m_xContextualCB(m_xBuilder->weld_check_button("checkCB_CONTEXTUALSPACING"))
 , m_xLineDist(m_xBuilder->weld_combo_box("comboLB_LINEDIST"))
 , 
m_xLineDistAtPercentBox(m_xBuilder->weld_metric_spin_button("spinED_LINEDISTPERCENT",
 FieldUnit::PERCENT))
diff --git a/include/svx/dlgctrl.hxx b/include/svx/dlgctrl.hxx
index 6625b0651496..a7c70d7be723 100644
--- a/include/svx/dlgctrl.hxx
+++ b/include/svx/dlgctrl.hxx
@@ -413,10 +413,10 @@ public:
 virtual void Paint( vcl::RenderContext& rRenderContext, const 
tools::Rectangle& rRect ) override;
 };
 
-class RelativeField;
+class SvxRelativeField;
 
 SVX_DLLPUBLIC void limitWidthForSidebar(weld::SpinButton& rSpinButton);
-SVX_DLLPUBLIC void limitWidthForSidebar(RelativeField& rMetricSpinButton);
+SVX_DLLPUBLIC void limitWidthForSidebar(SvxRelativeField& rMetricSpinButton);
 //tdf#130197 Give this toolbar a width as if it had 5 standard toolbutton 
entries
 SVX_DLLPUBLIC void padWidthForSidebar(weld::Tool

[Libreoffice-commits] core.git: extras/source include/svx solenv/bin svx/source

2020-02-02 Thread Caolán McNamara (via logerrit)
 extras/source/glade/libreoffice-catalog.xml.in |3 ---
 include/svx/relfld.hxx |7 ---
 solenv/bin/native-code.py  |1 -
 svx/source/dialog/relfld.cxx   |   23 ---
 4 files changed, 34 deletions(-)

New commits:
commit 075e365e20a75dd12c29b0b094fea986f3e1231a
Author: Caolán McNamara 
AuthorDate: Sat Feb 1 14:31:09 2020 +
Commit: Caolán McNamara 
CommitDate: Sun Feb 2 21:39:58 2020 +0100

SvxRelativeField is newly unused

Change-Id: Iaeb72e9aa7276736632a66f1eb75277a696e91e0
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/87831
Tested-by: Jenkins
Reviewed-by: Caolán McNamara 

diff --git a/extras/source/glade/libreoffice-catalog.xml.in 
b/extras/source/glade/libreoffice-catalog.xml.in
index 903553e985b5..b132e58b18f5 100644
--- a/extras/source/glade/libreoffice-catalog.xml.in
+++ b/extras/source/glade/libreoffice-catalog.xml.in
@@ -82,9 +82,6 @@
 
-
 
 
 #include 
-#include 
 #include 
 #include 
 
-class SAL_DLLPUBLIC_RTTI SvxRelativeField final : public MetricField
-{
-public:
-SvxRelativeField(vcl::Window* pParent, WinBits nBits, FieldUnit eUnit);
-};
-
 class SVX_DLLPUBLIC RelativeField
 {
 private:
diff --git a/solenv/bin/native-code.py b/solenv/bin/native-code.py
index 9f4704e82074..f8133a6d7723 100755
--- a/solenv/bin/native-code.py
+++ b/solenv/bin/native-code.py
@@ -515,7 +515,6 @@ custom_widgets = [
 'SearchResultsBox',
 'SidebarToolBox',
 'SvxColorValueSet',
-'SvxRelativeField',
 'TemplateDefaultView',
 ]
 
diff --git a/svx/source/dialog/relfld.cxx b/svx/source/dialog/relfld.cxx
index a6609d2009a4..d8db417a9717 100644
--- a/svx/source/dialog/relfld.cxx
+++ b/svx/source/dialog/relfld.cxx
@@ -18,29 +18,6 @@
  */
 
 #include 
-#include 
-
-SvxRelativeField::SvxRelativeField(
-vcl::Window *const pParent, WinBits const nBits, FieldUnit const eUnit)
-: MetricField( pParent, nBits)
-{
-SetUnit(eUnit);
-SetDecimalDigits( 2 );
-SetMin( 0 );
-SetMax(  );
-}
-
-extern "C" SAL_DLLPUBLIC_EXPORT void makeSvxRelativeField(VclPtr 
& rRet, const VclPtr & pParent, VclBuilder::stringmap & rMap)
-{
-
static_assert(std::is_same_v,
- decltype(makeSvxRelativeField)>);
-OUString const custom(BuilderUtils::extractCustomProperty(rMap));
-FieldUnit const eUnit(BuilderUtils::detectUnit(custom));
-rRet = VclPtr::Create(pParent,
-WB_BORDER | WB_SPIN | WB_REPEAT |
-WB_LEFT | WB_GROUP,
-eUnit);
-}
 
 RelativeField::RelativeField(std::unique_ptr pControl)
 : m_xSpinButton(std::move(pControl))
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: avmedia/source include/svx svx/source svx/uiconfig

2020-02-02 Thread Caolán McNamara (via logerrit)
 avmedia/source/framework/mediacontrol.cxx   |1 
 include/svx/relfld.hxx  |1 
 svx/source/sidebar/paragraph/ParaSpacingControl.cxx |   10 
 svx/source/sidebar/paragraph/ParaSpacingWindow.cxx  |  295 +++-
 svx/source/sidebar/paragraph/ParaSpacingWindow.hxx  |   60 ++--
 svx/uiconfig/ui/paralrspacing.ui|   43 ++
 svx/uiconfig/ui/paraulspacing.ui|   25 +
 7 files changed, 271 insertions(+), 164 deletions(-)

New commits:
commit 61fd0e0c27494fdda61e9e06490c50ef1147c1bd
Author: Caolán McNamara 
AuthorDate: Sat Feb 1 14:27:26 2020 +
Commit: Caolán McNamara 
CommitDate: Sun Feb 2 21:39:35 2020 +0100

weld ParaLRSpacingWindow & ParaULSpacingWindow

Change-Id: I9bd00ab28a84383cc484b5c58532f355da131999
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/87818
Reviewed-by: Caolán McNamara 
Tested-by: Caolán McNamara 

diff --git a/avmedia/source/framework/mediacontrol.cxx 
b/avmedia/source/framework/mediacontrol.cxx
index ddec4f90436d..a9c144b1e455 100644
--- a/avmedia/source/framework/mediacontrol.cxx
+++ b/avmedia/source/framework/mediacontrol.cxx
@@ -145,6 +145,7 @@ void MediaControl::Resize()
 vcl::Window *pChild = GetWindow(GetWindowType::FirstChild);
 assert(pChild);
 VclContainer::setLayoutAllocation(*pChild, Point(0, 0), GetSizePixel());
+Control::Resize();
 }
 
 void MediaControl::setState( const MediaItem& rItem )
diff --git a/include/svx/relfld.hxx b/include/svx/relfld.hxx
index 8f8c84dc38f3..7aa6b88d7c5b 100644
--- a/include/svx/relfld.hxx
+++ b/include/svx/relfld.hxx
@@ -66,6 +66,7 @@ public:
 void save_value() { m_xSpinButton->save_value(); }
 bool get_value_changed_from_saved() const { return 
m_xSpinButton->get_value_changed_from_saved(); }
 void set_size_request(int nWidth, int nHeight) { 
m_xSpinButton->set_size_request(nWidth, nHeight); }
+void grab_focus() { m_xSpinButton->grab_focus(); }
 Size get_preferred_size() const { return 
m_xSpinButton->get_preferred_size(); }
 weld::SpinButton& get_widget() { return m_xSpinButton->get_widget(); }
 
diff --git a/svx/source/sidebar/paragraph/ParaSpacingControl.cxx 
b/svx/source/sidebar/paragraph/ParaSpacingControl.cxx
index 29ce7e3bbc0d..d097a907aa8a 100644
--- a/svx/source/sidebar/paragraph/ParaSpacingControl.cxx
+++ b/svx/source/sidebar/paragraph/ParaSpacingControl.cxx
@@ -90,7 +90,7 @@ ParaAboveSpacingControl::ParaAboveSpacingControl(sal_uInt16 
nSlotId, sal_uInt16
 
 VclPtr ParaAboveSpacingControl::CreateItemWindow(vcl::Window* 
pParent)
 {
-VclPtr pWindow = 
VclPtr::Create(pParent, m_xFrame);
+VclPtr pWindow = 
VclPtr::Create(pParent);
 pWindow->Show();
 
 return pWindow;
@@ -105,7 +105,7 @@ ParaBelowSpacingControl::ParaBelowSpacingControl(sal_uInt16 
nSlotId, sal_uInt16
 
 VclPtr ParaBelowSpacingControl::CreateItemWindow(vcl::Window* 
pParent)
 {
-VclPtr pWindow = 
VclPtr::Create(pParent, m_xFrame);
+VclPtr pWindow = 
VclPtr::Create(pParent);
 pWindow->Show();
 
 return pWindow;
@@ -219,7 +219,7 @@ ParaLeftSpacingControl::ParaLeftSpacingControl(sal_uInt16 
nSlotId, sal_uInt16 nI
 
 VclPtr ParaLeftSpacingControl::CreateItemWindow(vcl::Window* 
pParent)
 {
-VclPtr pWindow = 
VclPtr::Create(pParent, m_xFrame);
+VclPtr pWindow = 
VclPtr::Create(pParent);
 pWindow->Show();
 
 return pWindow;
@@ -234,7 +234,7 @@ ParaRightSpacingControl::ParaRightSpacingControl(sal_uInt16 
nSlotId, sal_uInt16
 
 VclPtr ParaRightSpacingControl::CreateItemWindow(vcl::Window* 
pParent)
 {
-VclPtr pWindow = 
VclPtr::Create(pParent, m_xFrame);
+VclPtr pWindow = 
VclPtr::Create(pParent);
 pWindow->Show();
 
 return pWindow;
@@ -249,7 +249,7 @@ 
ParaFirstLineSpacingControl::ParaFirstLineSpacingControl(sal_uInt16 nSlotId, sal
 
 VclPtr ParaFirstLineSpacingControl::CreateItemWindow(vcl::Window* 
pParent)
 {
-VclPtr pWindow = 
VclPtr::Create(pParent, m_xFrame);
+VclPtr pWindow = 
VclPtr::Create(pParent);
 pWindow->Show();
 
 return pWindow;
diff --git a/svx/source/sidebar/paragraph/ParaSpacingWindow.cxx 
b/svx/source/sidebar/paragraph/ParaSpacingWindow.cxx
index 6dd4f4858c90..8ddbe0949e03 100644
--- a/svx/source/sidebar/paragraph/ParaSpacingWindow.cxx
+++ b/svx/source/sidebar/paragraph/ParaSpacingWindow.cxx
@@ -36,23 +36,27 @@ using namespace svx;
 
 // ParaULSpacingWindow
 
-ParaULSpacingWindow::ParaULSpacingWindow(vcl::Window* pParent, 
css::uno::Reference const & xFrame)
-: VclVBox(pParent)
+ParaULSpacingWindow::ParaULSpacingWindow(vcl::Window* pParent)
+: Control(pParent, WB_TABSTOP)
 , m_eUnit(MapUnit::MapTwip)
 {
-m_pUIBuilder.reset(new VclBuilder(this, getUIRootDir(),
-  "svx/ui/paraulspacing.ui",
-  "ParaULSpacingWindow",
-  xFrame));
-
-get(m_pAboveSpacing, "aboveparaspacing");
-get(m_pBelowSpacing, "belo

[Libreoffice-commits] core.git: include/vcl

2020-02-02 Thread Caolán McNamara (via logerrit)
 include/vcl/weld.hxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit f88cd56a4dfc9a1bea5e95c5778f0ce7b6af67dc
Author: Caolán McNamara 
AuthorDate: Sun Feb 2 16:04:08 2020 +
Commit: Caolán McNamara 
CommitDate: Sun Feb 2 21:37:16 2020 +0100

default should be false for non-toplevel window elements

Change-Id: I003a90144bc7c387509890887efa09f6beff8548
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/87829
Tested-by: Jenkins
Reviewed-by: Caolán McNamara 

diff --git a/include/vcl/weld.hxx b/include/vcl/weld.hxx
index 9bbf612b3375..742290822c32 100644
--- a/include/vcl/weld.hxx
+++ b/include/vcl/weld.hxx
@@ -2122,7 +2122,7 @@ public:
  const OString& treeviewid, bool bTakeOwnership = 
false)
 = 0;
 virtual std::unique_ptr weld_menu(const OString& id, bool 
bTakeOwnership = true) = 0;
-virtual std::unique_ptr weld_toolbar(const OString& id, bool 
bTakeOwnership = true)
+virtual std::unique_ptr weld_toolbar(const OString& id, bool 
bTakeOwnership = false)
 = 0;
 virtual std::unique_ptr create_size_group() = 0;
 /* return a Dialog suitable to take a screenshot of containing the 
contents of the .ui file.
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: bin/find-headers-to-move-inside-modules.py include/cppcanvas include/sfx2 include/unotest solenv/clang-format

2020-02-02 Thread Noel Grandin (via logerrit)
 bin/find-headers-to-move-inside-modules.py |   52 
 include/cppcanvas/font.hxx |   41 --
 include/sfx2/sidebar/ToolBox.hxx   |   53 -
 include/unotest/assertion_traits.hxx   |   42 --
 solenv/clang-format/blacklist  |2 -
 5 files changed, 52 insertions(+), 138 deletions(-)

New commits:
commit 14b6fae258fe74c5cccf1e6d63ff32ae698d0f6c
Author: Noel Grandin 
AuthorDate: Sun Feb 2 12:51:23 2020 +0200
Commit: Noel Grandin 
CommitDate: Sun Feb 2 19:38:58 2020 +0100

remove some unused headers

found with a little python script(include) and some grepping, so probably
not 100% reliable.

Change-Id: I1a26a37ef7297c2cc07ed5fd2e0af45280e64c13
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/87824
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/bin/find-headers-to-move-inside-modules.py 
b/bin/find-headers-to-move-inside-modules.py
new file mode 100755
index ..c8a9dc989069
--- /dev/null
+++ b/bin/find-headers-to-move-inside-modules.py
@@ -0,0 +1,52 @@
+#!/usr/bin/python
+
+# Look for headers inside include/ that can be moved into their respective 
modules.
+
+import subprocess
+import sys
+
+headerSet = set()
+a = subprocess.Popen("git ls-files include/", stdout=subprocess.PIPE, 
shell=True)
+with a.stdout as txt:
+for line in txt:
+header = line[8:].strip();
+if "README" in header: continue
+if header == "version.hrc": continue
+if header == "svtools/editimplementation.hxx": continue
+# ignore URE headers
+if header.startswith("IwyuFilter_include.yaml"): continue
+if header.startswith("cppu/"): continue
+if header.startswith("cppuhelper/"): continue
+if header.startswith("osl/"): continue
+if header.startswith("sal/"): continue
+if header.startswith("salhelper/"): continue
+if header.startswith("uno/"): continue
+# these are direct copies of mozilla code
+if header.startswith("onlineupdate/mozilla/"): continue
+headerSet.add(header)
+
+headerSetUnused = headerSet.copy()
+headerSetOnlyInOwnModule = headerSet.copy()
+a = subprocess.Popen("git grep '^#include <'", stdout=subprocess.PIPE, 
shell=True)
+with a.stdout as txt:
+for line in txt:
+idx1 = line.find("#include <")
+include = line[idx1 + 10 : len(line)-2]
+headerSetUnused.discard(include)
+#
+idx1 = line.find("/")
+includedFromModule = line[0 : idx1]
+idx1 = include.find("/")
+module = include[0 : idx1]
+if module != includedFromModule:
+headerSetOnlyInOwnModule.discard(include)
+
+print "completely unused"
+print ""
+for x in sorted(headerSetUnused):
+print x
+print ""
+print "only used in own module"
+print ""
+for x in sorted(headerSetOnlyInOwnModule):
+print x
diff --git a/include/cppcanvas/font.hxx b/include/cppcanvas/font.hxx
deleted file mode 100644
index e52a5778f56f..
--- a/include/cppcanvas/font.hxx
+++ /dev/null
@@ -1,41 +0,0 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*
- * This file is part of the LibreOffice project.
- *
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- *
- * This file incorporates work covered by the following license notice:
- *
- *   Licensed to the Apache Software Foundation (ASF) under one or more
- *   contributor license agreements. See the NOTICE file distributed
- *   with this work for additional information regarding copyright
- *   ownership. The ASF licenses this file to you under the Apache
- *   License, Version 2.0 (the "License"); you may not use this file
- *   except in compliance with the License. You may obtain a copy of
- *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
- */
-
-#ifndef INCLUDED_CPPCANVAS_FONT_HXX
-#define INCLUDED_CPPCANVAS_FONT_HXX
-
-#include 
-
-/* Definition of Font class */
-
-namespace cppcanvas
-{
-
-class Font
-{
-public:
-virtual ~Font() {}
-};
-
-typedef std::shared_ptr< ::cppcanvas::Font > FontSharedPtr;
-}
-
-#endif // INCLUDED_CPPCANVAS_FONT_HXX
-
-/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
diff --git a/include/sfx2/sidebar/ToolBox.hxx b/include/sfx2/sidebar/ToolBox.hxx
deleted file mode 100644
index 834d7cb2b7a0..
--- a/include/sfx2/sidebar/ToolBox.hxx
+++ /dev/null
@@ -1,53 +0,0 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
-/*
- * This file is part of the LibreOffice project.
- *
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL 

[Libreoffice-commits] core.git: include/svx sd/source svx/inc svx/Library_svxcore.mk svx/source

2020-02-02 Thread Stephan Bergmann (via logerrit)
 include/svx/ColorSets.hxx|2 
 include/svx/CommonStyleManager.hxx   |2 
 include/svx/EnhancedCustomShape2d.hxx|2 
 include/svx/EnhancedCustomShapeFunctionParser.hxx|4 -
 include/svx/EnhancedCustomShapeGeometry.hxx  |8 +-
 include/svx/EnhancedCustomShapeTypeNames.hxx |6 -
 include/svx/ImageMapInfo.hxx |2 
 include/svx/PaletteManager.hxx   |2 
 include/svx/ParseContext.hxx |4 -
 include/svx/SvxColorValueSet.hxx |4 -
 include/svx/SvxNumOptionsTabPageHelper.hxx   |2 
 include/svx/SvxPresetListBox.hxx |2 
 include/svx/XPropertyEntry.hxx   |2 
 include/svx/camera3d.hxx |2 
 include/svx/charthelper.hxx  |2 
 include/svx/chrtitem.hxx |   10 +-
 include/svx/clipfmtitem.hxx  |2 
 include/svx/colorbox.hxx |4 -
 include/svx/colorwindow.hxx  |8 +-
 include/svx/cube3d.hxx   |2 
 include/svx/dataaccessdescriptor.hxx |2 
 include/svx/dbaexchange.hxx  |6 -
 include/svx/deflt3d.hxx  |2 
 include/svx/dialmgr.hxx  |4 -
 include/svx/dlgutil.hxx  |6 -
 include/svx/drawitem.hxx |   14 ++--
 include/svx/e3ditem.hxx  |2 
 include/svx/e3dsceneupdater.hxx  |2 
 include/svx/e3dundo.hxx  |2 
 include/svx/extedit.hxx  |4 -
 include/svx/extrud3d.hxx |2 
 include/svx/extrusionbar.hxx |4 -
 include/svx/fmdmod.hxx   |2 
 include/svx/fmdpage.hxx  |2 
 include/svx/fmgridcl.hxx |4 -
 include/svx/fmgridif.hxx |4 -
 include/svx/fmmodel.hxx  |2 
 include/svx/fmpage.hxx   |2 
 include/svx/fmsearch.hxx |2 
 include/svx/fmshell.hxx  |4 -
 include/svx/fmtools.hxx  |6 -
 include/svx/fmview.hxx   |2 
 include/svx/fontworkbar.hxx  |4 -
 include/svx/fontworkgallery.hxx  |2 
 include/svx/framelink.hxx|2 
 include/svx/framelinkarray.hxx   |2 
 include/svx/galctrl.hxx  |2 
 include/svx/gallery.hxx  |2 
 include/svx/gallery1.hxx |2 
 include/svx/galleryitem.hxx  |2 
 include/svx/galmisc.hxx  |4 -
 include/svx/galtheme.hxx |2 
 include/svx/graphichelper.hxx|2 
 include/svx/grfcrop.hxx  |2 
 include/svx/gridctrl.hxx |2 
 include/svx/helperhittest3d.hxx  |2 
 include/svx/hexcolorcontrol.hxx  |2 
 include/svx/itextprovider.hxx|2 
 include/svx/langbox.hxx  |4 -
 include/svx/lathe3d.hxx  |2 
 include/svx/linectrl.hxx |2 
 include/svx/obj3d.hxx|4 -
 include/svx/objfac3d.hxx |2 
 include/svx/pagenumberlistbox.hxx|2 
 include/svx/papersizelistbox.hxx |2 
 include/svx/polygn3d.hxx |2 
 include/svx/polypolygoneditor.hxx|2 
 include/svx/samecontentlistbox.hxx   |2 
 include/svx/scene3d.hxx  |2 
 include/svx/sdangitm.hxx |2 
 include/svx/sdasitm.hxx  |4 -

[Libreoffice-commits] Changes to 'refs/tags/libcdr-0.1.6'

2020-02-02 Thread Libreoffice Gerrit user
Tag 'libcdr-0.1.6' created by Fridrich Štrba  at 
2020-02-02 15:35 +

Tagging 0.1.6 Release - extended support until CDR 21

Changes since libcdr-0.1.5-8:
---
 0 files changed
---
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] libcdr.git: 2 commits - src/lib

2020-02-02 Thread Libreoffice Gerrit user
 src/lib/CDRParser.cpp |   46 +-
 1 file changed, 13 insertions(+), 33 deletions(-)

New commits:
commit bd969c36b580f5de0cc30fe1badf4f1b8361c05d
Author: Fridrich Štrba 
AuthorDate: Sun Feb 2 12:09:49 2020 +0100
Commit: Fridrich Štrba 
CommitDate: Sun Feb 2 12:09:49 2020 +0100

Fix txsm for version 15

Change-Id: I188be62b02807f6704ce78ef2a9b1011667ed46a

diff --git a/src/lib/CDRParser.cpp b/src/lib/CDRParser.cpp
index d58f281..40b9b68 100644
--- a/src/lib/CDRParser.cpp
+++ b/src/lib/CDRParser.cpp
@@ -2911,7 +2911,7 @@ void 
libcdr::CDRParser::readTxsm(librevenge::RVNGInputStream *input, unsigned le
   std::map::const_iterator iter = 
m_fillStyles.find(fillId);
   if (iter != m_fillStyles.end())
 style.m_fillStyle = iter->second;
-  if (m_version >= 1500)
+  if (m_version >= 1600)
 input->seek(48, librevenge::RVNG_SEEK_CUR);
 }
 if (fl2&0x80) // Font Outl Colour
commit 496e288d9e5450ed7db8324b51a1767377f0125a
Author: Fridrich Štrba 
AuthorDate: Sat Feb 1 20:28:36 2020 +0100
Commit: Fridrich Štrba 
CommitDate: Sun Feb 2 11:30:45 2020 +0100

improve readFild for versions 13 and up

Change-Id: I9d5d2f92da990b9e46998517bdf1b750ddb00315

diff --git a/src/lib/CDRParser.cpp b/src/lib/CDRParser.cpp
index 6bd5dc9..d58f281 100644
--- a/src/lib/CDRParser.cpp
+++ b/src/lib/CDRParser.cpp
@@ -1156,6 +1156,9 @@ libcdr::CDRColor 
libcdr::CDRParser::readColor(librevenge::RVNGInputStream *input
 colorModel = readU8(input);
 colorValue = readU32(input);
   }
+
+  CDR_DEBUG_MSG(("CDRParser::redColor --> colorModel 0x%x -- colorValue 
0x%x\n", colorModel, colorValue));
+
   return libcdr::CDRColor(colorModel, colorValue);
 }
 
@@ -1758,13 +1761,8 @@ void 
libcdr::CDRParser::readFild(librevenge::RVNGInputStream *input, unsigned le
   if (!_redirectX6Chunk(&input, length))
 throw GenericException();
   unsigned fillId = readU32(input);
-  unsigned short v13flag = 0;
   if (m_version >= 1300)
-  {
-input->seek(4, librevenge::RVNG_SEEK_CUR);
-v13flag = readU16(input);
-input->seek(2, librevenge::RVNG_SEEK_CUR);
-  }
+input->seek(8, librevenge::RVNG_SEEK_CUR);
   unsigned short fillType = readU16(input);
   libcdr::CDRColor color1;
   libcdr::CDRColor color2;
@@ -1818,14 +1816,11 @@ void 
libcdr::CDRParser::readFild(librevenge::RVNGInputStream *input, unsigned le
 {
   libcdr::CDRGradientStop stop;
   stop.m_color = readColor(input);
-  if (m_version >= 1300)
-  {
-if (v13flag == 0x9e || (m_version >= 1600 && v13flag == 0x96))
-  input->seek(26, librevenge::RVNG_SEEK_CUR);
-else
-  input->seek(5, librevenge::RVNG_SEEK_CUR);
-  }
-  stop.m_offset = (double)readUnsigned(input) / 100.0;
+  if (m_version >= 1400)
+input->seek(26, librevenge::RVNG_SEEK_CUR);
+  else if (m_version >= 1300)
+input->seek(5, librevenge::RVNG_SEEK_CUR);
+  stop.m_offset = (double)(readUnsigned(input) & 0x) / 100.0;
   if (m_version >= 1300)
 input->seek(3, librevenge::RVNG_SEEK_CUR);
   gradient.m_stops.push_back(stop);
@@ -1867,12 +1862,7 @@ void 
libcdr::CDRParser::readFild(librevenge::RVNGInputStream *input, unsigned le
   input->seek(1, librevenge::RVNG_SEEK_CUR);
 color1 = readColor(input);
 if (m_version >= 1300)
-{
-  if (v13flag == 0x94 || (m_version >= 1600 && v13flag == 0x8c))
-input->seek(31, librevenge::RVNG_SEEK_CUR);
-  else
-input->seek(10, librevenge::RVNG_SEEK_CUR);
-}
+  input->seek(31, librevenge::RVNG_SEEK_CUR);
 color2 = readColor(input);
 imageFill = libcdr::CDRImageFill(patternId, patternWidth, patternHeight, 
isRelative, tileOffsetX, tileOffsetY, rcpOffset, flags);
   }
@@ -1921,12 +1911,7 @@ void 
libcdr::CDRParser::readFild(librevenge::RVNGInputStream *input, unsigned le
   case 10: // Full color
   {
 if (m_version >= 1300)
-{
-  if (v13flag == 0x4e)
-input->seek(28, librevenge::RVNG_SEEK_CUR);
-  else
-input->seek(4, librevenge::RVNG_SEEK_CUR);
-}
+  input->seek(28, librevenge::RVNG_SEEK_CUR);
 else
   input->seek(2, librevenge::RVNG_SEEK_CUR);
 unsigned patternId = readUnsigned(input);
@@ -1966,12 +1951,7 @@ void 
libcdr::CDRParser::readFild(librevenge::RVNGInputStream *input, unsigned le
 if (m_version < 600)
   fillType = 10;
 if (m_version >= 1300)
-{
-  if (v13flag == 0x18e)
-input->seek(36, librevenge::RVNG_SEEK_CUR);
-  else
-input->seek(1, librevenge::RVNG_SEEK_CUR);
-}
+  input->seek(36, librevenge::RVNG_SEEK_CUR);
 else
   input->seek(2, librevenge::RVNG_SEEK_CUR);
 unsigned patternId = readU32(input);
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/

[Libreoffice-commits] core.git: sw/inc sw/qa sw/source uitest/writer_tests

2020-02-02 Thread ayhanyalcinsoy (via logerrit)
 sw/inc/strings.hrc |5 +++--
 sw/qa/extras/layout/layout.cxx |2 +-
 sw/qa/extras/odfimport/odfimport.cxx   |6 +++---
 sw/qa/extras/ooxmlexport/ooxmlexport9.cxx  |4 ++--
 sw/qa/extras/ooxmlimport/ooxmlimport.cxx   |4 ++--
 sw/qa/extras/rtfimport/rtfimport.cxx   |   12 ++--
 sw/qa/extras/tiledrendering/tiledrendering.cxx |   10 +-
 sw/qa/extras/uiwriter/uiwriter.cxx |8 
 sw/qa/extras/uiwriter/uiwriter2.cxx|2 +-
 sw/qa/extras/ww8export/ww8export3.cxx  |4 ++--
 sw/qa/uitest/writer_tests3/insertPageFooter.py |4 ++--
 sw/qa/uitest/writer_tests5/tdf107494.py|8 
 sw/source/core/doc/SwStyleNameMapper.cxx   |4 ++--
 sw/source/core/unocore/unosett.cxx |2 +-
 sw/source/core/unocore/unostyle.cxx|2 +-
 sw/source/filter/xml/xmlimp.cxx|2 +-
 sw/source/ui/index/cnttab.cxx  |2 +-
 sw/source/uibase/app/docst.cxx |3 +--
 sw/source/uibase/app/docstyle.cxx  |9 +++--
 sw/source/uibase/utlui/uitool.cxx  |4 ++--
 uitest/writer_tests/insertPageHeader.py|4 ++--
 21 files changed, 49 insertions(+), 52 deletions(-)

New commits:
commit 0298a702b32bdc4c4711cf31461169e549153b39
Author: ayhanyalcinsoy 
AuthorDate: Sat Jan 11 15:54:49 2020 +0300
Commit: Maxim Monastirsky 
CommitDate: Sun Feb 2 15:40:45 2020 +0100

tdf#129568 Rename Default Style to Default Paragraph/Page/Table Style

Change-Id: I21672c9b78e52c3c9b2687cb2c0ab21dcf67f19a
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/86538
Tested-by: Jenkins
Reviewed-by: Heiko Tietze 
Tested-by: Heiko Tietze 
Reviewed-by: Maxim Monastirsky 

diff --git a/sw/inc/strings.hrc b/sw/inc/strings.hrc
index fbb64babe662..755bcc58e47c 100644
--- a/sw/inc/strings.hrc
+++ b/sw/inc/strings.hrc
@@ -24,6 +24,7 @@
 #define NNC_(Context, StringSingular, StringPlural) reinterpret_cast(Context "\004" u8##StringSingular "\004" u8##StringPlural)
 
 // Format names
+#define STR_POOLCHR_STANDARDNC_("STR_POOLCHR_STANDARD", 
"Default Character Style")
 #define STR_POOLCHR_FOOTNOTENC_("STR_POOLCHR_FOOTNOTE", 
"Footnote Characters")
 #define STR_POOLCHR_PAGENO  NC_("STR_POOLCHR_PAGENO", 
"Page Number")
 #define STR_POOLCHR_LABEL   NC_("STR_POOLCHR_LABEL", 
"Caption Characters")
@@ -60,7 +61,7 @@
 #define STR_POOLFRM_WATERSIGN   NC_("STR_POOLFRM_WATERSIGN", 
"Watermark")
 #define STR_POOLFRM_LABEL   NC_("STR_POOLFRM_LABEL", 
"Labels")
 // Template names
-#define STR_POOLCOLL_STANDARD   NC_("STR_POOLCOLL_STANDARD", 
"Default Style")
+#define STR_POOLCOLL_STANDARD   NC_("STR_POOLCOLL_STANDARD", 
"Default Paragraph Style")
 #define STR_POOLCOLL_TEXT   NC_("STR_POOLCOLL_TEXT", "Text 
Body")
 #define STR_POOLCOLL_TEXT_IDENT NC_("STR_POOLCOLL_TEXT_IDENT", 
"First Line Indent")
 #define STR_POOLCOLL_TEXT_NEGIDENT  
NC_("STR_POOLCOLL_TEXT_NEGIDENT", "Hanging Indent")
@@ -188,7 +189,7 @@
 #define STR_POOLCOLL_HTML_DDNC_("STR_POOLCOLL_HTML_DD", 
"List Contents")
 #define STR_POOLCOLL_HTML_DTNC_("STR_POOLCOLL_HTML_DT", 
"List Heading")
 //page style names
-#define STR_POOLPAGE_STANDARD   NC_("STR_POOLPAGE_STANDARD", 
"Default Style")
+#define STR_POOLPAGE_STANDARD   NC_("STR_POOLPAGE_STANDARD", 
"Default Page Style")
 #define STR_POOLPAGE_FIRST  NC_("STR_POOLPAGE_FIRST", 
"First Page")
 #define STR_POOLPAGE_LEFT   NC_("STR_POOLPAGE_LEFT", "Left 
Page")
 #define STR_POOLPAGE_RIGHT  NC_("STR_POOLPAGE_RIGHT", 
"Right Page")
diff --git a/sw/qa/extras/layout/layout.cxx b/sw/qa/extras/layout/layout.cxx
index 746b8a068aaf..4ed828a0fb56 100644
--- a/sw/qa/extras/layout/layout.cxx
+++ b/sw/qa/extras/layout/layout.cxx
@@ -462,7 +462,7 @@ CPPUNIT_TEST_FIXTURE(SwLayoutWriter, 
testRedlineFlysInHeader)
 SwWrtShell* pWrtShell = pTextDoc->GetDocShell()->GetWrtShell();
 SwRootFrame* pLayout(pWrtShell->GetLayout());
 CPPUNIT_ASSERT(!pLayout->IsHideRedlines());
-pWrtShell->ChangeHeaderOrFooter("Default Style", /*bHeader*/ true, /*bOn*/ 
true, false);
+pWrtShell->ChangeHeaderOrFooter("Default Page Style", /*bHeader*/ true, 
/*bOn*/ true, false);
 CPPUNIT_ASSERT(
 pWrtShell
 ->IsInHeaderFooter()); // assume this is supposed to put cursor in 
the new header...
diff --git a/sw/qa/extras/odfimport/odfimport.cxx 
b/sw/qa/extras/odfimport/odfimport.cxx
index 7e4e4a252ae7..56df38c6d686 100644
--- a/sw/qa/extras/odfimport/odfimport.cxx
+++ b/sw/qa/extras/odfimport/odfimport.cxx
@@ -253,7 +253,7 @@ DECLARE_ODFIMPORT_TEST(te

[Libreoffice-commits] online.git: 2 commits - cypress_test/integration_tests cypress_test/README

2020-02-02 Thread Tamás Zolnai (via logerrit)
 cypress_test/README  |   26 ++-
 cypress_test/integration_tests/mobile/styles_spec.js |  146 +++
 2 files changed, 169 insertions(+), 3 deletions(-)

New commits:
commit 8ce8a90a37d61d3d5df7bbd7e7e10ea620c8570f
Author: Tamás Zolnai 
AuthorDate: Fri Jan 31 20:12:20 2020 +0100
Commit: Tamás Zolnai 
CommitDate: Sun Feb 2 12:23:18 2020 +0100

cypress: mobile: Add some test about styles.

Change-Id: Ie61f5bd2a5203d501db60fc6f75e878c728d3a96

diff --git a/cypress_test/integration_tests/mobile/styles_spec.js 
b/cypress_test/integration_tests/mobile/styles_spec.js
new file mode 100644
index 0..7a5016bde
--- /dev/null
+++ b/cypress_test/integration_tests/mobile/styles_spec.js
@@ -0,0 +1,146 @@
+/* global describe it cy beforeEach require afterEach*/
+
+var helper = require('../common/helper');
+
+describe('Apply/modify styles.', function() {
+   beforeEach(function() {
+   helper.loadTestDoc('simple.odt', true);
+
+   // Click on edit button
+   cy.get('#mobile-edit-button').click();
+   });
+
+   afterEach(function() {
+   helper.afterAllMobile();
+   });
+
+   function applyStyle(styleName) {
+   // Do a new selection
+   helper.selectAllMobile();
+
+   // Open mobile wizard
+   cy.get('#tb_actionbar_item_mobile_wizard')
+   .should('not.have.class', 'disabled')
+   .click();
+
+   // Change font name
+   cy.get('#applystyle')
+   .click();
+
+   cy.wait(200);
+
+   cy.get('#mobile-wizard-back')
+   .should('be.visible');
+
+   cy.get('.mobile-wizard.ui-combobox-text')
+   .contains(styleName)
+   .scrollIntoView()
+   .click();
+
+   // Combobox entry contains the selected font name
+   if (styleName === 'Clear formatting') {
+   cy.get('#applystyle .ui-header-right .entry-value')
+   .contains('Default Style');
+   } else {
+   cy.get('#applystyle .ui-header-right .entry-value')
+   .contains(styleName);
+   }
+
+   // Close mobile wizard
+   cy.get('#tb_actionbar_item_mobile_wizard')
+   .click();
+   }
+
+   it('Apply new style.', function() {
+   // Apply Title style
+   applyStyle('Title');
+
+   helper.copyTextToClipboard();
+
+   cy.get('#copy-paste-container p font')
+   .should('have.attr', 'face', 'Liberation Sans, 
sans-serif');
+   cy.get('#copy-paste-container p font font')
+   .should('have.attr', 'style', 'font-size: 28pt');
+   });
+
+   it('Clear style.', function() {
+   // Apply Title style
+   applyStyle('Title');
+
+   helper.copyTextToClipboard();
+
+   cy.get('#copy-paste-container p font')
+   .should('have.attr', 'face', 'Liberation Sans, 
sans-serif');
+   cy.get('#copy-paste-container p font font')
+   .should('have.attr', 'style', 'font-size: 28pt');
+
+   // Clear formatting
+   applyStyle('Clear formatting');
+
+   helper.copyTextToClipboard();
+
+   cy.get('#copy-paste-container p')
+   .should('have.attr', 'style', 'margin-bottom: 0in; 
line-height: 100%');
+   });
+
+   it('Modify existing style.', function() {
+   // Apply Title style
+   applyStyle('Title');
+
+   helper.copyTextToClipboard();
+
+   cy.get('#copy-paste-container p font')
+   .should('have.attr', 'face', 'Liberation Sans, 
sans-serif');
+   cy.get('#copy-paste-container p font font')
+   .should('have.attr', 'style', 'font-size: 28pt');
+
+   // Open mobile wizard
+   cy.get('#tb_actionbar_item_mobile_wizard')
+   .should('not.have.class', 'disabled')
+   .click();
+
+   // Apply italic
+   cy.get('#Italic')
+   .click();
+
+   helper.copyTextToClipboard();
+
+   cy.get('#copy-paste-container p i')
+   .should('exist');
+
+   // Open mobile wizard
+   cy.get('#tb_actionbar_item_mobile_wizard')
+   .should('not.have.class', 'disabled')
+   .click();
+
+   cy.get('#StyleUpdateByExample')
+   .click();
+
+   // Clear formatting
+   applyStyle('Clear formatting');
+
+   // Apply Titl

[Libreoffice-commits] core.git: 2 commits - sw/inc sw/source

2020-02-02 Thread Noel Grandin (via logerrit)
 sw/inc/accmap.hxx |4 ++--
 sw/inc/doc.hxx|3 ++-
 sw/source/core/doc/DocumentRedlineManager.cxx |4 ++--
 sw/source/core/doc/doc.cxx|4 ++--
 sw/source/core/doc/docftn.cxx |2 +-
 sw/source/core/doc/doclay.cxx |4 ++--
 sw/source/core/doc/doctxm.cxx |2 +-
 sw/source/core/doc/ftnidx.cxx |4 ++--
 sw/source/core/undo/unsect.cxx|2 +-
 9 files changed, 15 insertions(+), 14 deletions(-)

New commits:
commit 220cdd6f2c178a115dd2776658fdaaf826315eed
Author: Noel Grandin 
AuthorDate: Sun Feb 2 12:41:43 2020 +0200
Commit: Noel Grandin 
CommitDate: Sun Feb 2 12:51:33 2020 +0100

std::set->o3tl::sorted_vector in SwDoc

Change-Id: Id8f6df99245aeb25e1c32ef4d7c06187c8ab353e
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/87823
Tested-by: Jenkins
Reviewed-by: Noel Grandin 

diff --git a/sw/inc/doc.hxx b/sw/inc/doc.hxx
index f19ea9d40269..20954f7ed608 100644
--- a/sw/inc/doc.hxx
+++ b/sw/inc/doc.hxx
@@ -21,6 +21,7 @@
 
 // SwDoc interfaces
 #include 
+#include 
 #include 
 #include "swdllapi.h"
 #include "swtypes.hxx"
@@ -680,7 +681,7 @@ public:
 OUString GetUniqueFrameName() const;
 OUString GetUniqueShapeName() const;
 
-std::set GetAllLayouts();
+o3tl::sorted_vector GetAllLayouts();
 
 void SetFlyName( SwFlyFrameFormat& rFormat, const OUString& rName );
 const SwFlyFrameFormat* FindFlyByName( const OUString& rName, SwNodeType 
nNdTyp = SwNodeType::NONE ) const;
diff --git a/sw/source/core/doc/DocumentRedlineManager.cxx 
b/sw/source/core/doc/DocumentRedlineManager.cxx
index 57621a2f6cd9..768f4772a9c2 100644
--- a/sw/source/core/doc/DocumentRedlineManager.cxx
+++ b/sw/source/core/doc/DocumentRedlineManager.cxx
@@ -936,7 +936,7 @@ void DocumentRedlineManager::SetRedlineFlags( RedlineFlags 
eMode )
 CheckAnchoredFlyConsistency(m_rDoc);
 CHECK_REDLINE( *this )
 
-std::set hiddenLayouts;
+o3tl::sorted_vector hiddenLayouts;
 if (eShowMode == (RedlineFlags::ShowInsert | 
RedlineFlags::ShowDelete))
 {
 // sw_redlinehide: the problem here is that MoveFromSection
@@ -944,7 +944,7 @@ void DocumentRedlineManager::SetRedlineFlags( RedlineFlags 
eMode )
 // SwRangeRedline has wrong positions until after the nodes
 // are all moved, so fix things up by force by re-creating
 // all merged frames from scratch.
-std::set const layouts(m_rDoc.GetAllLayouts());
+o3tl::sorted_vector const 
layouts(m_rDoc.GetAllLayouts());
 for (SwRootFrame *const pLayout : layouts)
 {
 if (pLayout->IsHideRedlines())
diff --git a/sw/source/core/doc/doc.cxx b/sw/source/core/doc/doc.cxx
index 4ad631e560b2..7cf8984bbae9 100644
--- a/sw/source/core/doc/doc.cxx
+++ b/sw/source/core/doc/doc.cxx
@@ -1184,7 +1184,7 @@ static bool lcl_CheckSmartTagsAgain( const SwNodePtr& 
rpNd, void*  )
  */
 void SwDoc::SpellItAgainSam( bool bInvalid, bool bOnlyWrong, bool bSmartTags )
 {
-std::set aAllLayouts = GetAllLayouts();
+o3tl::sorted_vector aAllLayouts = GetAllLayouts();
 assert(getIDocumentLayoutAccess().GetCurrentLayout() && "SpellAgain: 
Where's my RootFrame?");
 if( bInvalid )
 {
@@ -1207,7 +1207,7 @@ void SwDoc::InvalidateAutoCompleteFlag()
 SwRootFrame* pTmpRoot = getIDocumentLayoutAccess().GetCurrentLayout();
 if( pTmpRoot )
 {
-std::set aAllLayouts = GetAllLayouts();
+o3tl::sorted_vector aAllLayouts = GetAllLayouts();
 for( auto aLayout : aAllLayouts )
 aLayout->AllInvalidateAutoCompleteWords();
 for( sal_uLong nNd = 1, nCnt = GetNodes().Count(); nNd < nCnt; ++nNd )
diff --git a/sw/source/core/doc/docftn.cxx b/sw/source/core/doc/docftn.cxx
index 882959ede139..9bd2a9ec63c7 100644
--- a/sw/source/core/doc/docftn.cxx
+++ b/sw/source/core/doc/docftn.cxx
@@ -316,7 +316,7 @@ void SwDoc::SetFootnoteInfo(const SwFootnoteInfo& rInfo)
 
 if (pTmpRoot)
 {
-std::set aAllLayouts = GetAllLayouts();
+o3tl::sorted_vector aAllLayouts = GetAllLayouts();
 if ( bFootnotePos )
 for( auto aLayout : aAllLayouts )
 aLayout->AllRemoveFootnotes();
diff --git a/sw/source/core/doc/doclay.cxx b/sw/source/core/doc/doclay.cxx
index b5a98cf724dd..4b43892c4abe 100644
--- a/sw/source/core/doc/doclay.cxx
+++ b/sw/source/core/doc/doclay.cxx
@@ -1657,9 +1657,9 @@ bool SwDoc::IsInVerticalText( const SwPosition& rPos ) 
const
 return SvxFrameDirection::Vertical_RL_TB == nDir || 
SvxFrameDirection::Vertical_LR_TB == nDir;
 }
 
-std::set SwDoc::GetAllLayouts()
+o3tl::sorted_vector SwDoc::GetAllLayouts()
 {
-std::set aAllLayouts;
+o3tl::sorted_vector aAllLayouts;
 SwViewShell *pStart = getIDocu

[Libreoffice-commits] core.git: include/vcl sfx2/source vcl/source

2020-02-02 Thread Caolán McNamara (via logerrit)
 include/vcl/layout.hxx |   30 ++---
 sfx2/source/notebookbar/DropdownBox.cxx|1 
 sfx2/source/notebookbar/PriorityMergedHBox.cxx |1 
 vcl/source/window/layout.cxx   |   30 +
 4 files changed, 40 insertions(+), 22 deletions(-)

New commits:
commit dc9bf7ca261e91adb32af3e51a51998a402a5752
Author: Caolán McNamara 
AuthorDate: Sat Feb 1 21:30:39 2020 +
Commit: Caolán McNamara 
CommitDate: Sun Feb 2 12:33:04 2020 +0100

don't include vcl/button.hxx from vcl/layout.hxx

Change-Id: I16a1b392c33734ef89f26e7ff9318573e9bfce88
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/87817
Tested-by: Jenkins
Reviewed-by: Caolán McNamara 

diff --git a/include/vcl/layout.hxx b/include/vcl/layout.hxx
index 7989c011cc7f..c7631e1308cb 100644
--- a/include/vcl/layout.hxx
+++ b/include/vcl/layout.hxx
@@ -11,7 +11,6 @@
 #define INCLUDED_VCL_LAYOUT_HXX
 
 #include 
-#include 
 #include 
 #include 
 #include 
@@ -459,34 +458,21 @@ private:
 sal_Int32 m_nTopPadding;
 };
 
+class DisclosureButton;
+class CheckBox;
+
 class VclExpander final : public VclBin
 {
 public:
-VclExpander(vcl::Window *pParent)
-: VclBin(pParent)
-, m_bResizeTopLevel(true)
-, m_pDisclosureButton(VclPtr::Create(this))
-{
-m_pDisclosureButton->SetToggleHdl(LINK(this, VclExpander, ClickHdl));
-m_pDisclosureButton->Show();
-}
-virtual ~VclExpander() override { disposeOnce(); }
+VclExpander(vcl::Window *pParent);
+virtual ~VclExpander() override;
 virtual void dispose() override;
 virtual vcl::Window *get_child() override;
 virtual const vcl::Window *get_child() const override;
 virtual bool set_property(const OString &rKey, const OUString &rValue) 
override;
-bool get_expanded() const
-{
-return m_pDisclosureButton->IsChecked();
-}
-void set_expanded(bool bExpanded)
-{
-m_pDisclosureButton->Check(bExpanded);
-}
-void set_label(const OUString& rLabel)
-{
-m_pDisclosureButton->SetText(rLabel);
-}
+bool get_expanded() const;
+void set_expanded(bool bExpanded);
+void set_label(const OUString& rLabel);
 virtual void StateChanged(StateChangedType nType) override;
 void  SetExpandedHdl( const Link& rLink ) { 
maExpandedHdl = rLink; }
 private:
diff --git a/sfx2/source/notebookbar/DropdownBox.cxx 
b/sfx2/source/notebookbar/DropdownBox.cxx
index 104bb31ecb5a..450cae82a1e8 100644
--- a/sfx2/source/notebookbar/DropdownBox.cxx
+++ b/sfx2/source/notebookbar/DropdownBox.cxx
@@ -18,6 +18,7 @@
  */
 
 #include 
+#include 
 #include 
 #include "DropdownBox.hxx"
 
diff --git a/sfx2/source/notebookbar/PriorityMergedHBox.cxx 
b/sfx2/source/notebookbar/PriorityMergedHBox.cxx
index faebfbcd4121..8a5bcd014c4d 100644
--- a/sfx2/source/notebookbar/PriorityMergedHBox.cxx
+++ b/sfx2/source/notebookbar/PriorityMergedHBox.cxx
@@ -18,6 +18,7 @@
 */
 
 #include 
+#include 
 #include 
 #include 
 #include "PriorityHBox.hxx"
diff --git a/vcl/source/window/layout.cxx b/vcl/source/window/layout.cxx
index 56c93c2c3b10..2426d056a542 100644
--- a/vcl/source/window/layout.cxx
+++ b/vcl/source/window/layout.cxx
@@ -10,6 +10,7 @@
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -1541,6 +1542,35 @@ bool VclAlignment::set_property(const OString &rKey, 
const OUString &rValue)
 return true;
 }
 
+VclExpander::VclExpander(vcl::Window *pParent)
+: VclBin(pParent)
+, m_bResizeTopLevel(true)
+, m_pDisclosureButton(VclPtr::Create(this))
+{
+m_pDisclosureButton->SetToggleHdl(LINK(this, VclExpander, ClickHdl));
+m_pDisclosureButton->Show();
+}
+
+VclExpander::~VclExpander()
+{
+disposeOnce();
+}
+
+bool VclExpander::get_expanded() const
+{
+return m_pDisclosureButton->IsChecked();
+}
+
+void VclExpander::set_expanded(bool bExpanded)
+{
+m_pDisclosureButton->Check(bExpanded);
+}
+
+void VclExpander::set_label(const OUString& rLabel)
+{
+m_pDisclosureButton->SetText(rLabel);
+}
+
 void VclExpander::dispose()
 {
 m_pDisclosureButton.disposeAndClear();
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] core.git: include/sfx2 include/svtools include/vcl sfx2/source svx/source vcl/source

2020-02-02 Thread Caolán McNamara (via logerrit)
 include/sfx2/sidebar/ControlFactory.hxx |4 ++--
 include/sfx2/sidebar/TabItem.hxx|2 +-
 include/svtools/valueset.hxx|2 +-
 include/vcl/button.hxx  |9 -
 sfx2/source/sidebar/ControlFactory.cxx  |2 +-
 sfx2/source/sidebar/TabItem.cxx |6 +++---
 svx/source/tbxctrls/tbcontrl.cxx|2 --
 vcl/source/control/button.cxx   |5 -
 8 files changed, 8 insertions(+), 24 deletions(-)

New commits:
commit e2205c4876723876bcaf1dd5ce494debab97591a
Author: Caolán McNamara 
AuthorDate: Sat Feb 1 21:41:22 2020 +
Commit: Caolán McNamara 
CommitDate: Sun Feb 2 12:29:17 2020 +0100

no difference between ImageRadioButton and RadioButton

Change-Id: Iae5b7fe329273f34d3e94f1136acdac0d55d1ced
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/87816
Tested-by: Jenkins
Reviewed-by: Caolán McNamara 

diff --git a/include/sfx2/sidebar/ControlFactory.hxx 
b/include/sfx2/sidebar/ControlFactory.hxx
index 26ef4a7134e3..7deebf1ab92c 100644
--- a/include/sfx2/sidebar/ControlFactory.hxx
+++ b/include/sfx2/sidebar/ControlFactory.hxx
@@ -23,7 +23,7 @@
 #include 
 
 class CheckBox;
-class ImageRadioButton;
+class RadioButton;
 namespace vcl { class Window; }
 
 namespace sfx2 { namespace sidebar {
@@ -40,7 +40,7 @@ public:
 */
 static VclPtr CreateMenuButton (vcl::Window* pParentWindow);
 
-static VclPtr CreateTabItem (vcl::Window* pParentWindow);
+static VclPtr CreateTabItem (vcl::Window* pParentWindow);
 };
 
 
diff --git a/include/sfx2/sidebar/TabItem.hxx b/include/sfx2/sidebar/TabItem.hxx
index 43dd79acbede..8d54640a680c 100644
--- a/include/sfx2/sidebar/TabItem.hxx
+++ b/include/sfx2/sidebar/TabItem.hxx
@@ -28,7 +28,7 @@ namespace sfx2 { namespace sidebar {
 /** A single button in the tab bar.
 */
 class TabItem final
-: public ImageRadioButton
+: public RadioButton
 {
 public:
 TabItem (vcl::Window* pParentWindow);
diff --git a/include/svtools/valueset.hxx b/include/svtools/valueset.hxx
index 86036fe7130a..66ba3b212f4f 100644
--- a/include/svtools/valueset.hxx
+++ b/include/svtools/valueset.hxx
@@ -69,7 +69,7 @@ class ListBox
 WinBits
 
 WB_RADIOSEL If set the selection will be drawn like an
-ImageRadioButton. This does only make sense if the image
+RadioButton. This does only make sense if the image
 is at least 8 pixel smaller on each side than the item
 and also WB_DOUBLEBORDER is set and as color
 COL_WINDOWWORKSPACE is specified.
diff --git a/include/vcl/button.hxx b/include/vcl/button.hxx
index d0aa24757ae1..e5a5b7de51f5 100644
--- a/include/vcl/button.hxx
+++ b/include/vcl/button.hxx
@@ -499,15 +499,6 @@ public:
  ImageButton( vcl::Window* pParent, WinBits nStyle = 0 );
 };
 
-class VCL_DLLPUBLIC ImageRadioButton : public RadioButton
-{
-ImageRadioButton( const ImageRadioButton & ) = delete;
-ImageRadioButton & operator= ( const ImageRadioButton & ) 
= delete;
-
-public:
-explicitImageRadioButton( vcl::Window* pParent );
-};
-
 class VCL_DLLPUBLIC TriStateBox final : public CheckBox
 {
 TriStateBox( const TriStateBox & ) = delete;
diff --git a/sfx2/source/sidebar/ControlFactory.cxx 
b/sfx2/source/sidebar/ControlFactory.cxx
index b65f0b9c1779..de5e8123ddf3 100644
--- a/sfx2/source/sidebar/ControlFactory.cxx
+++ b/sfx2/source/sidebar/ControlFactory.cxx
@@ -28,7 +28,7 @@ VclPtr ControlFactory::CreateMenuButton 
(vcl::Window* pParentWindow)
 return VclPtr::Create(pParentWindow);
 }
 
-VclPtr ControlFactory::CreateTabItem (vcl::Window* 
pParentWindow)
+VclPtr ControlFactory::CreateTabItem (vcl::Window* pParentWindow)
 {
 return VclPtr::Create(pParentWindow);
 }
diff --git a/sfx2/source/sidebar/TabItem.cxx b/sfx2/source/sidebar/TabItem.cxx
index 160bec8a2075..013ff688d19c 100644
--- a/sfx2/source/sidebar/TabItem.cxx
+++ b/sfx2/source/sidebar/TabItem.cxx
@@ -31,8 +31,8 @@ using namespace css::uno;
 namespace sfx2::sidebar {
 
 TabItem::TabItem (vcl::Window* pParentWindow)
-: ImageRadioButton(pParentWindow),
-  mbIsLeftButtonDown(false)
+: RadioButton(pParentWindow, 0)
+, mbIsLeftButtonDown(false)
 {
 SetStyle(GetStyle() | WB_TABSTOP | WB_DIALOGCONTROL | WB_NOPOINTERFOCUS);
 
SetBackground(Theme::GetPaint(Theme::Paint_TabBarBackground).GetWallpaper());
@@ -67,7 +67,7 @@ void TabItem::MouseMove(const MouseEvent& rEvent)
 {
 if (rEvent.IsEnterWindow() || rEvent.IsLeaveWindow())
 Invalidate();
-ImageRadioButton::MouseMove(rEvent);
+RadioButton::MouseMove(rEvent);
 }
 
 void TabItem::MouseButtonDown(const MouseEvent& rMouseEvent)
diff --git a/svx/source/tbxctrls/tbcontrl.cxx b/svx/source/tbxctrls/tbcontrl.cxx
index 7b6d2d9acb3b..583030205a36 100644
--- a/svx/source/tbxctrls/tbcontrl.cxx
+++ b/svx/source/tbxctrls/tbcontrl.cxx
@@ -2639,8 +

[Libreoffice-commits] core.git: Branch 'libreoffice-6-4' - slideshow/Library_OGLTrans.mk

2020-02-02 Thread Caolán McNamara (via logerrit)
 slideshow/Library_OGLTrans.mk |1 +
 1 file changed, 1 insertion(+)

New commits:
commit 81147e61b2c86dc54078660307b8812e4238f90f
Author: Caolán McNamara 
AuthorDate: Fri Jan 31 21:45:11 2020 +
Commit: Rene Engelhard 
CommitDate: Sun Feb 2 11:42:01 2020 +0100

opengl slide transitions not working with glm >= GLM 0.9.9.0

tracked it down to...

Removed default initialization, use GLM_FORCE_CTOR_INIT to restore the old 
behavior
so adding in GLM_FORCE_CTOR_INIT to get them working again

Change-Id: I1c6e7d8eb748fce40f0c518ff708708e5fb1e3d2
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/87790
Tested-by: Jenkins
Reviewed-by: Rene Engelhard 
Tested-by: Rene Engelhard 

diff --git a/slideshow/Library_OGLTrans.mk b/slideshow/Library_OGLTrans.mk
index 4eca2a1ecaa3..9b64181d6a46 100644
--- a/slideshow/Library_OGLTrans.mk
+++ b/slideshow/Library_OGLTrans.mk
@@ -17,6 +17,7 @@ endif
 
 $(eval $(call gb_Library_add_defs,OGLTrans,\
 -DGLM_FORCE_RADIANS \
+-DGLM_FORCE_CTOR_INIT \
 ))
 
 $(eval $(call gb_Library_use_sdk_api,OGLTrans))
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits
diff --git a/cypress_test/integration_tests/desktop/copy_paste_spec.js 
b/cypress_test/integration_tests/desktop/copy_paste_spec.js
index 015905d31..4f7ae7461 100644
--- a/cypress_test/integration_tests/desktop/copy_paste_spec.js
+++ b/cypress_test/integration_tests/desktop/copy_paste_spec.js
@@ -1,4 +1,4 @@
 /* global describe it cy beforeEach require expect*/
 
 var helper = require('../common/helper');
 
@@ -7,6 +7,10 @@ describe('Clipboard operations.', function() {
helper.loadTestDoc('simple.odt');
});
 
+   afterEach(function() {
+   helper.afterAll();
+   });
+
@@ -1,4 +1,4 @@
-/* global describe it cy beforeEach require expect*/
+/* global describe it cy beforeEach require expect afterEach*/
 
 var helper = require('../common/helper');
it('Copy and Paste text.', function() {
// Select some text
cy.get('#document-container').dblclick();